==> conan-1.14.6.tar.gz: conan-1.14.6/conans/test/functional/old/remove_old_export_sources_layout_test.py <==
import os
import unittest

from conans.model.ref import ConanFileReference
from conans.paths import EXPORT_SOURCES_DIR_OLD
from conans.test.utils.test_files import temp_folder
from conans.test.utils.tools import TestClient, TestServer
from conans.util.files import tar_extract


class DoNotKeepOldExportSourcesLayoutTest(unittest.TestCase):

    def test_basic(self):
        """ check that we do not generate anymore tgz with .c_src.
        also, they are not present any more in the cache layout, even if they come from a .c_src
        tgz server file
        """
        test_server = TestServer()
        servers = {"default": test_server}
        client = TestClient(servers=servers, users={"default": [("lasote", "mypass")]})
        client.save({"conanfile.py": """from conans import ConanFile
class MyPkg(ConanFile):
    name= "Pkg"
    version = "0.1"
    exports_sources = "*.txt"
""", "myfile.txt": "Hello world"})
        client.run("export . lasote/testing")
        client.run("upload Pkg/0.1@lasote/testing")
        client.run("remove * -f")
        client.run("search")
        self.assertIn("There are no packages", client.user_io.out)
        ref = ConanFileReference.loads("Pkg/0.1@lasote/testing")
        rev, _ = servers["default"].server_store.get_last_revision(ref)
        ref = ref.copy_with_rev(rev)
        path = test_server.server_store.export(ref)
        sources_tgz = os.path.join(path, "conan_sources.tgz")
        self.assertTrue(os.path.exists(sources_tgz))
        folder = temp_folder()
        with open(sources_tgz, 'rb') as file_handler:
            tar_extract(file_handler, folder)
        self.assertEqual(os.listdir(folder), ["myfile.txt"])
        # Now install again
        client.run("install Pkg/0.1@lasote/testing --build=missing")
        export = client.cache.export(ref)
        self.assertNotIn(EXPORT_SOURCES_DIR_OLD, os.listdir(export))
        export_sources = client.cache.export_sources(ref)
        self.assertEqual(os.listdir(export_sources), ["myfile.txt"])

==> conan-1.17.3.tar.gz: conan-1.17.3/conans/test/functional/old/remove_old_export_sources_layout_test.py <==
import os
import unittest

from conans.model.ref import ConanFileReference
from conans.paths import EXPORT_SOURCES_DIR_OLD
from conans.test.utils.test_files import temp_folder
from conans.test.utils.tools import TestClient, TestServer
from conans.util.files import tar_extract


class DoNotKeepOldExportSourcesLayoutTest(unittest.TestCase):

    def test_basic(self):
        """ check that we do not generate anymore tgz with .c_src.
        also, they are not present any more in the cache layout, even if they come from a .c_src
        tgz server file
        """
        test_server = TestServer()
        servers = {"default": test_server}
        client = TestClient(servers=servers, users={"default": [("lasote", "mypass")]})
        client.save({"conanfile.py": """from conans import ConanFile
class MyPkg(ConanFile):
    name= "Pkg"
    version = "0.1"
    exports_sources = "*.txt"
""", "myfile.txt": "Hello world"})
        client.run("export . lasote/testing")
        client.run("upload Pkg/0.1@lasote/testing")
        client.run("remove * -f")
        client.run("search")
        self.assertIn("There are no packages", client.user_io.out)
        ref = ConanFileReference.loads("Pkg/0.1@lasote/testing")
        rev, _ = servers["default"].server_store.get_last_revision(ref)
        ref = ref.copy_with_rev(rev)
        path = test_server.server_store.export(ref)
        sources_tgz = os.path.join(path, "conan_sources.tgz")
        self.assertTrue(os.path.exists(sources_tgz))
        folder = temp_folder()
        with open(sources_tgz, 'rb') as file_handler:
            tar_extract(file_handler, folder)
        self.assertEqual(os.listdir(folder), ["myfile.txt"])
        # Now install again
        client.run("install Pkg/0.1@lasote/testing --build=missing")
        export = client.cache.package_layout(ref).export()
        self.assertNotIn(EXPORT_SOURCES_DIR_OLD, os.listdir(export))
        export_sources = client.cache.package_layout(ref).export_sources()
        self.assertEqual(os.listdir(export_sources), ["myfile.txt"])
